==> jupyter_book-1.0.3.tar.gz: jupyter_book-1.0.3/README.md <==
# <img src="https://raw.githubusercontent.com/executablebooks/jupyter-book/master/docs/images/logo-square.svg" width=40 /> Jupyter Book

[![Jupyter Book Badge](docs/images/badge.svg)](https://jupyterbook.org)
[![CircleCI](https://circleci.com/gh/executablebooks/jupyter-book.svg?style=svg)](https://circleci.com/gh/executablebooks/jupyter-book)
[![codecov](https://codecov.io/gh/executablebooks/jupyter-book/branch/master/graph/badge.svg)](https://codecov.io/gh/executablebooks/jupyter-book)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.2561065.svg)](https://doi.org/10.5281/zenodo.2561065)
[![PyPI][pypi-badge]][pypi-link]
[![Conda][conda-badge]][conda-link]

Jupyter Book is an open-source tool for building publication-quality books and documents from computational material.

Jupyter Book allows users to

* write their content in [markdown files](https://myst-parser.readthedocs.io/en/latest/) or [Jupyter](https://jupyter.org/) notebooks,
* include computational elements (e.g., code cells) in either type,
* include rich syntax such as citations, cross-references, and numbered equations, and
* using a simple command, run the embedded code cells, [cache](https://jupyter-cache.readthedocs.io/en/latest/) the outputs and convert this content into:
    * a web-based interactive book and
    * a publication-quality PDF.

## Governance of this project
Jupyter Book 1.x is now in a maintenance phase, where new feature requests have lower priority than bugfixes. Jupyter Book 2.x will be built on the new [MyST-MD document engine](https://mystmd.org/). See [our blog post](https://executablebooks.org/en/latest/blog/2024-05-20-jupyter-book-myst/) for more information.

## Contribute or improve the book

Notice some inefficient CSS? A typo in the text? Want to add a cool feature so that others
can enjoy the improvements to Jupyter Books? Check out the [Jupyter Book Contributor's
Guide](https://jupyterbook.org/contribute/intro.html). We'd love your help!

## Acknowledgements

Jupyter Book is maintained and primarily developed by
the [Executable Book Project](https://executablebooks.org).

[pypi-badge]: https://img.shields.io/pypi/v/jupyter-book.svg
[pypi-link]: https://pypi.org/project/jupyter-book
[conda-badge]: https://anaconda.org/conda-forge/jupyter-book/badges/version.svg
[conda-link]: https://anaconda.org/conda-forge/jupyter-book

==> jupyter_book-1.0.4.post1.tar.gz: jupyter_book-1.0.4.post1/README.md <==
# <img src="https://raw.githubusercontent.com/executablebooks/jupyter-book/master/docs/images/logo-square.svg" width=40 /> Jupyter Book

[![Jupyter Book Badge](docs/images/badge.svg)](https://jupyterbook.org)
[![CircleCI](https://circleci.com/gh/executablebooks/jupyter-book.svg?style=svg)](https://circleci.com/gh/executablebooks/jupyter-book)
[![codecov](https://codecov.io/gh/executablebooks/jupyter-book/branch/master/graph/badge.svg)](https://codecov.io/gh/executablebooks/jupyter-book)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.2561065.svg)](https://doi.org/10.5281/zenodo.2561065)
[![PyPI][pypi-badge]][pypi-link]
[![Conda][conda-badge]][conda-link]

Jupyter Book is an open-source tool for building publication-quality books and documents from computational material.

Jupyter Book allows users to

* write their content in [markdown files](https://myst-parser.readthedocs.io/en/latest/) or [Jupyter](https://jupyter.org/) notebooks,
* include computational elements (e.g., code cells) in either type,
* include rich syntax such as citations, cross-references, and numbered equations, and
* using a simple command, run the embedded code cells, [cache](https://jupyter-cache.readthedocs.io/en/latest/) the outputs and convert this content into:
  * a web-based interactive book and
  * a publication-quality PDF.

## Governance of this project and Jupyter Book 2.x

Jupyter Book 1.x is now in a maintenance phase, where new feature requests have lower priority than bugfixes.

Jupyter Book 2.x will be built on the new [MyST-MD document engine](https://mystmd.org/). See [this blog post](https://executablebooks.org/en/latest/blog/2024-05-20-jupyter-book-myst/) for more information on our plans, and [this blog post](https://blog.jupyterbook.org/posts/2024-11-15-jupyter-book-2-alpha) about the alpha release of Jupyter Book 2.x.

Jupyter Book 2.x is currently being developed on the `next` branch, and documentation for Jupyter Book 2.x can be found at [next.jupyterbook.org](https://next.jupyterbook.org).

## Contribute or improve the book

Notice some inefficient CSS? A typo in the text? Want to add a cool feature so that others
can enjoy the improvements to Jupyter Books? Check out the [Jupyter Book Contributor's
Guide](https://jupyterbook.org/contribute/intro.html). We'd love your help!

## Acknowledgements

Jupyter Book is maintained and primarily developed by
the [Executable Book Project](https://executablebooks.org).

[pypi-badge]: https://img.shields.io/pypi/v/jupyter-book.svg
[pypi-link]: https://pypi.org/project/jupyter-book
[conda-badge]: https://anaconda.org/conda-forge/jupyter-book/badges/version.svg
[conda-link]: https://anaconda.org/conda-forge/jupyter-book
